import greenfoot.*;     // (World, Actor, GreenfootImage, and Greenfoot)

import java.util.List;
import java.util.ArrayList;

/**
 * Vombato.<br/>
 * Un vombato si muove in avanti finch lo pu fare altrimenti gira a sinistra.<br/>
 * Se un vombato trova una foglia la mangia.
 * 
 * @author Michael Kolling<br/>Valentino Condoluci
 * @version 1.0<br/>1.0.1 
 *
 */
public class Vombato extends Actor
{
    private static final int EST   = 0;
    private static final int OVEST = 1;
    private static final int NORD  = 2;
    private static final int SUD   = 3;
    private              int direzione;
    private              int foglieMangiate;

    public Vombato()
    {
        nuovaDirezione(EST);
        foglieMangiate = 0;
    }
    /**
     * Decide cosa fa il vombato
     */
    public void act()
    {
             if(trovataFoglia())    mangiaFoglia();
        else if(haStrada())         nuovaPosizione();
        else                        giraSinistra();
    }
    /**
     * Controlla se nello stesso posto c' una foglia.
     */
    public boolean trovataFoglia()
    {
        Actor foglia = getOneObjectAtOffset(0,0,Foglia.class);
        return (foglia != null); 
    }    
    /**
     * Mangia una foglia.
     */
    public void mangiaFoglia()
    {
        Actor foglia = getOneObjectAtOffset(0, 0, Foglia.class);
        if(foglia != null) 
        {            
            getWorld().removeObject(foglia); // mangia la foglia
            foglieMangiate++;                // incrementa il contatore
        }
    }
    /**
     * Si muove una cella nella direzione corrente.
     */
    public void nuovaPosizione()
    {
        if(!haStrada()) 
        {
            return;
        }
        switch(direzione) 
        {
            case SUD   : setLocation(getX()  , getY()+1);  break;
            case EST   : setLocation(getX()+1, getY()  );  break;
            case NORD  : setLocation(getX()  , getY()-1);  break;
            case OVEST : setLocation(getX()-1, getY()  );  break;
        }
    }

    /**
     * Controlla se si pu muovere in avanti.
     */
    public boolean haStrada()
    {
        World myWorld = getWorld();
        int x = getX();
        int y = getY();
        switch(direzione) 
        {
            case SUD   : y++; break;
            case EST   : x++; break;
            case NORD  : y--; break;
            case OVEST : x--; break;
        }
        if(x >= myWorld.getWidth() || y >= myWorld.getHeight()) 
            return false;
        else if(x < 0 || y < 0)                                      
            return false;

        return true;
    }
    /**
     * Si gira a sinistra.
     */
    public void giraSinistra()
    {
        switch(direzione) 
        {
            case SUD   : nuovaDirezione(EST  ); break;
            case EST   : nuovaDirezione(NORD ); break;
            case NORD  : nuovaDirezione(OVEST); break;
            case OVEST : nuovaDirezione(SUD  ); break;
        }
    }
    /**
     * Imposta la direzione.
     */
    public void nuovaDirezione(int direzione)
    {
        this.direzione = direzione;
        switch(direzione) 
        {
            case SUD   : setRotation( 90); break;
            case EST   : setRotation(  0); break;
            case NORD  : setRotation(270); break;
            case OVEST : setRotation(180); break;
            default    :                   break;
        }
    }
    /**
     * Dice quante foglie ha mangiato.
     */
    public int quanteFoglieMangiate()
    {
        return foglieMangiate;
    }
}